@@ -1,7 +1,7 @@
 module Pundit
   module Generators
     class InstallGenerator < ::Rails::Generators::Base
-      source_root File.expand_path(File.join(File.dirname(__FILE__), 'templates'))
+      source_root File.expand_path('templates', __dir__)
 
       def copy_application_policy
         template 'application_policy.rb', 'app/policies/application_policy.rb'
